@@ -156,6 +156,9 @@ class FakeFS(object):
             node._content = ''.join(global_rd.choice(choices) for n in range(global_rd.randint(4,200)))
         return node._content
 
+    def cat_bytes(self, path):
+        return self.cat(path)
+
     def mkdir(self, path):
         self.put(path, isdir=True)
 
@@ -177,6 +180,7 @@ class FakeFS(object):
                 self.nodes.append(generate_fake_dir(path=parent_dir))
         return node
 
+
 class FakeRemoteFS(FakeFS):
     def __init__(self, mgm):
         self.mgm = mgm.rstrip('/')
@@ -259,6 +263,9 @@ class FakeCommandInterceptor:
     def cat(self, path, flags):
         return FakeFSTransaction('cat', path)
 
+    def cat_bytes(self, path, flags):
+        return FakeFSTransaction('cat', path)
+
 
 class FakeGfalInterceptor(FakeCommandInterceptor):
 
